Q-Measure
=========

.. automodule:: viqa.nr_metrics.qmeasure
    :exclude-members: QMeasure

   
.. rubric:: Classes

.. currentmodule:: viqa.nr_metrics.qmeasure

.. autosummary::
    :toctree: generated/
    :template: class.rst

    QMeasure